#line 1 "../../../src/common/ip_parsers.rl"

#include <lighttpd/ip_parsers.h>


#line 7 "ip_parsers.c"
static const unsigned char _ipv4_parser_key_offsets[] = {
	0, 0, 2, 5, 7, 10, 12, 15, 
	17, 25, 27, 34, 36, 42, 44, 47, 
	49, 52, 54, 57, 59, 65, 67, 70, 
	72, 75, 77, 80, 82, 89, 91, 97, 
	99, 102, 104, 107, 109, 112, 114, 121, 
	123, 129, 129, 129, 129
};

static const char _ipv4_parser_trans_keys[] = {
	48, 57, 46, 48, 57, 48, 57, 46, 
	48, 57, 48, 57, 46, 48, 57, 48, 
	57, 0, 32, 47, 58, 9, 13, 48, 
	57, 48, 57, 0, 32, 58, 9, 13, 
	48, 57, 48, 57, 0, 32, 9, 13, 
	48, 57, 48, 57, 46, 48, 57, 48, 
	57, 46, 48, 57, 48, 57, 46, 48, 
	57, 48, 57, 0, 32, 9, 13, 48, 
	57, 48, 57, 46, 48, 57, 48, 57, 
	46, 48, 57, 48, 57, 46, 48, 57, 
	48, 57, 0, 32, 47, 9, 13, 48, 
	57, 48, 57, 0, 32, 9, 13, 48, 
	57, 48, 57, 46, 48, 57, 48, 57, 
	46, 48, 57, 48, 57, 46, 48, 57, 
	48, 57, 0, 32, 58, 9, 13, 48, 
	57, 48, 57, 0, 32, 9, 13, 48, 
	57, 0
};

static const char _ipv4_parser_single_lengths[] = {
	0, 0, 1, 0, 1, 0, 1, 0, 
	4, 0, 3, 0, 2, 0, 1, 0, 
	1, 0, 1, 0, 2, 0, 1, 0, 
	1, 0, 1, 0, 3, 0, 2, 0, 
	1, 0, 1, 0, 1, 0, 3, 0, 
	2, 0, 0, 0, 0
};

static const char _ipv4_parser_range_lengths[] = {
	0, 1, 1, 1, 1, 1, 1, 1, 
	2, 1, 2, 1, 2, 1, 1, 1, 
	1, 1, 1, 1, 2, 1, 1, 1, 
	1, 1, 1, 1, 2, 1, 2, 1, 
	1, 1, 1, 1, 1, 1, 2, 1, 
	2, 0, 0, 0, 0
};

static const unsigned char _ipv4_parser_index_offsets[] = {
	0, 0, 2, 5, 7, 10, 12, 15, 
	17, 24, 26, 32, 34, 39, 41, 44, 
	46, 49, 51, 54, 56, 61, 63, 66, 
	68, 71, 73, 76, 78, 84, 86, 91, 
	93, 96, 98, 101, 103, 106, 108, 114, 
	116, 121, 122, 123, 124
};

static const char _ipv4_parser_trans_targs[] = {
	2, 0, 3, 2, 0, 4, 0, 5, 
	4, 0, 6, 0, 7, 6, 0, 8, 
	0, 41, 41, 9, 11, 41, 8, 0, 
	10, 0, 41, 41, 11, 41, 10, 0, 
	12, 0, 41, 41, 41, 12, 0, 14, 
	0, 15, 14, 0, 16, 0, 17, 16, 
	0, 18, 0, 19, 18, 0, 20, 0, 
	42, 42, 42, 20, 0, 22, 0, 23, 
	22, 0, 24, 0, 25, 24, 0, 26, 
	0, 27, 26, 0, 28, 0, 43, 43, 
	29, 43, 28, 0, 30, 0, 43, 43, 
	43, 30, 0, 32, 0, 33, 32, 0, 
	34, 0, 35, 34, 0, 36, 0, 37, 
	36, 0, 38, 0, 44, 44, 39, 44, 
	38, 0, 40, 0, 44, 44, 44, 40, 
	0, 0, 0, 0, 0, 0
};

static const char _ipv4_parser_trans_actions[] = {
	1, 0, 2, 3, 0, 1, 0, 2, 
	3, 0, 1, 0, 2, 3, 0, 1, 
	0, 4, 4, 2, 2, 4, 3, 0, 
	1, 0, 5, 5, 6, 5, 3, 0, 
	1, 0, 7, 7, 7, 3, 0, 1, 
	0, 2, 3, 0, 1, 0, 2, 3, 
	0, 1, 0, 2, 3, 0, 1, 0, 
	4, 4, 4, 3, 0, 1, 0, 2, 
	3, 0, 1, 0, 2, 3, 0, 1, 
	0, 2, 3, 0, 1, 0, 4, 4, 
	2, 4, 3, 0, 1, 0, 5, 5, 
	5, 3, 0, 1, 0, 2, 3, 0, 
	1, 0, 2, 3, 0, 1, 0, 2, 
	3, 0, 1, 0, 4, 4, 2, 4, 
	3, 0, 1, 0, 7, 7, 7, 3, 
	0, 0, 0, 0, 0, 0
};

static const int ipv4_parser_start = 1;
static const int ipv4_parser_first_final = 41;
static const int ipv4_parser_error = 0;

static const int ipv4_parser_en_ipv4 = 13;
static const int ipv4_parser_en_ipv4_cidr = 21;
static const int ipv4_parser_en_ipv4_socket = 31;
static const int ipv4_parser_en_ipv4_socket_cidr = 1;

#line 33 "../../../src/common/ip_parsers.rl"


gboolean li_parse_ipv4(const char *str, guint32 *ip, guint32 *netmask, guint16 *port) {
	guint8 *data = (guint8*) ip;
	const char *p = str;
	gboolean res = TRUE;
	int cs, tmpval = 0, i = 0;

	if (netmask) *netmask = 0xffffffffu;
	if (port) *port = 0;

	
#line 124 "ip_parsers.c"
	{
	}
#line 45 "../../../src/common/ip_parsers.rl"

	cs = netmask
		? (port ? ipv4_parser_en_ipv4_socket_cidr : ipv4_parser_en_ipv4_cidr)
		: (port ? ipv4_parser_en_ipv4_socket      : ipv4_parser_en_ipv4);
	
#line 133 "ip_parsers.c"
	{
	int _klen;
	const char *_keys;
	int _trans;

	if ( cs == 0 )
		goto _out;
_resume:
	_keys = _ipv4_parser_trans_keys + _ipv4_parser_key_offsets[cs];
	_trans = _ipv4_parser_index_offsets[cs];

	_klen = _ipv4_parser_single_lengths[cs];
	if ( _klen > 0 ) {
		const char *_lower = _keys;
		const char *_mid;
		const char *_upper = _keys + _klen - 1;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + ((_upper-_lower) >> 1);
			if ( (*p) < *_mid )
				_upper = _mid - 1;
			else if ( (*p) > *_mid )
				_lower = _mid + 1;
			else {
				_trans += (_mid - _keys);
				goto _match;
			}
		}
		_keys += _klen;
		_trans += _klen;
	}

	_klen = _ipv4_parser_range_lengths[cs];
	if ( _klen > 0 ) {
		const char *_lower = _keys;
		const char *_mid;
		const char *_upper = _keys + (_klen<<1) - 2;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + (((_upper-_lower) >> 1) & ~1);
			if ( (*p) < _mid[0] )
				_upper = _mid - 2;
			else if ( (*p) > _mid[1] )
				_lower = _mid + 2;
			else {
				_trans += ((_mid - _keys)>>1);
				goto _match;
			}
		}
		_trans += _klen;
	}

_match:
	cs = _ipv4_parser_trans_targs[_trans];

	if ( _ipv4_parser_trans_actions[_trans] == 0 )
		goto _again;

	switch ( _ipv4_parser_trans_actions[_trans] ) {
	case 3:
#line 8 "../../../src/common/ip_parsers.rl"
	{ tmpval = 10*tmpval + ((*p) - '0'); }
	break;
	case 2:
#line 11 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 255) { res = FALSE; {p++; goto _out; } }
		data[i++] = tmpval;
	}
	break;
	case 6:
#line 16 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 32) { res = FALSE; {p++; goto _out; } }
		*netmask = htonl(~((1 << (32-tmpval)) - 1));
	}
	break;
	case 1:
#line 7 "../../../src/common/ip_parsers.rl"
	{ tmpval = 0; }
#line 8 "../../../src/common/ip_parsers.rl"
	{ tmpval = 10*tmpval + ((*p) - '0'); }
	break;
	case 4:
#line 11 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 255) { res = FALSE; {p++; goto _out; } }
		data[i++] = tmpval;
	}
#line 25 "../../../src/common/ip_parsers.rl"
	{ cs = ipv4_parser_first_final; {p++; goto _out; } }
	break;
	case 5:
#line 16 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 32) { res = FALSE; {p++; goto _out; } }
		*netmask = htonl(~((1 << (32-tmpval)) - 1));
	}
#line 25 "../../../src/common/ip_parsers.rl"
	{ cs = ipv4_parser_first_final; {p++; goto _out; } }
	break;
	case 7:
#line 20 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 65535) { res = FALSE; {p++; goto _out; } }
		*port = tmpval;
	}
#line 25 "../../../src/common/ip_parsers.rl"
	{ cs = ipv4_parser_first_final; {p++; goto _out; } }
	break;
#line 248 "ip_parsers.c"
	}

_again:
	if ( cs == 0 )
		goto _out;
	p += 1;
	goto _resume;
	_out: {}
	}
#line 50 "../../../src/common/ip_parsers.rl"

	return res && cs >= ipv4_parser_first_final;
}


#line 264 "ip_parsers.c"
static const short _ipv6_parser_key_offsets[] = {
	0, 0, 8, 15, 22, 29, 30, 37, 
	50, 52, 55, 57, 60, 62, 69, 71, 
	77, 90, 103, 112, 115, 121, 133, 145, 
	156, 169, 171, 174, 176, 179, 181, 188, 
	201, 214, 223, 226, 232, 244, 256, 268, 
	280, 287, 299, 311, 323, 331, 336, 347, 
	358, 369, 376, 383, 390, 397, 398, 405, 
	415, 417, 420, 422, 425, 427, 431, 433, 
	436, 441, 443, 449, 459, 469, 475, 478, 
	481, 490, 499, 507, 517, 519, 522, 524, 
	527, 529, 533, 543, 553, 559, 562, 565, 
	574, 583, 592, 601, 608, 617, 626, 635, 
	640, 642, 650, 658, 666, 674, 681, 688, 
	695, 696, 703, 715, 717, 720, 722, 725, 
	727, 733, 745, 757, 765, 768, 773, 784, 
	795, 805, 817, 819, 822, 824, 827, 829, 
	835, 847, 859, 867, 870, 875, 886, 897, 
	908, 919, 926, 937, 948, 959, 966, 970, 
	980, 990, 1000, 1007, 1014, 1021, 1028, 1029, 
	1036, 1045, 1047, 1050, 1052, 1055, 1057, 1060, 
	1064, 1073, 1082, 1087, 1090, 1092, 1100, 1108, 
	1115, 1124, 1126, 1129, 1131, 1134, 1136, 1139, 
	1148, 1157, 1162, 1165, 1167, 1175, 1183, 1191, 
	1199, 1206, 1214, 1222, 1230, 1234, 1235, 1242, 
	1249, 1256, 1264, 1271, 1278, 1285, 1286, 1293, 
	1306, 1308, 1311, 1313, 1316, 1318, 1325, 1327, 
	1333, 1346, 1359, 1368, 1371, 1377, 1389, 1401, 
	1412, 1425, 1427, 1430, 1432, 1435, 1437, 1444, 
	1457, 1470, 1479, 1482, 1488, 1500, 1512, 1524, 
	1536, 1543, 1555, 1567, 1579, 1587, 1592, 1603, 
	1614, 1625, 1632, 1639, 1646, 1653, 1654, 1661, 
	1671, 1673, 1676, 1678, 1681, 1683, 1687, 1689, 
	1692, 1696, 1706, 1716, 1722, 1725, 1728, 1737, 
	1746, 1754, 1764, 1766, 1769, 1771, 1774, 1776, 
	1780, 1790, 1800, 1806, 1809, 1812, 1821, 1830, 
	1839, 1848, 1855, 1864, 1873, 1882, 1887, 1889, 
	1897, 1905, 1913, 1921, 1928, 1935, 1942, 1943, 
	1950, 1962, 1964, 1967, 1969, 1972, 1974, 1980, 
	1992, 2004, 2012, 2015, 2020, 2031, 2042, 2052, 
	2064, 2066, 2069, 2071, 2074, 2076, 2082, 2094, 
	2106, 2114, 2117, 2122, 2133, 2144, 2155, 2166, 
	2173, 2184, 2195, 2206, 2213, 2217, 2227, 2237, 
	2247, 2254, 2261, 2268, 2275, 2276, 2283, 2292, 
	2294, 2297, 2299, 2302, 2304, 2307, 2312, 2314, 
	2320, 2329, 2338, 2343, 2346, 2348, 2356, 2364, 
	2371, 2380, 2382, 2385, 2387, 2390, 2392, 2395, 
	2404, 2413, 2418, 2421, 2423, 2431, 2439, 2447, 
	2455, 2462, 2470, 2478, 2486, 2490, 2491, 2498, 
	2505, 2512, 2512, 2512, 2512
};

static const char _ipv6_parser_trans_keys[] = {
	58, 91, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 58, 48, 
	57, 65, 70, 97, 102, 58, 58, 48, 
	57, 65, 70, 97, 102, 0, 32, 46, 
	47, 58, 9, 13, 48, 57, 65, 70, 
	97, 102, 48, 57, 46, 48, 57, 48, 
	57, 46, 48, 57, 48, 57, 0, 32, 
	47, 9, 13, 48, 57, 48, 57, 0, 
	32, 9, 13, 48, 57, 0, 32, 46, 
	47, 58, 9, 13, 48, 57, 65, 70, 
	97, 102, 0, 32, 46, 47, 58, 9, 
	13, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 47, 58, 9, 13, 48, 57, 
	46, 48, 57, 0, 32, 47, 58, 9, 
	13, 0, 32, 47, 58, 9, 13, 48, 
	57, 65, 70, 97, 102, 0, 32, 47, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 0, 32, 47, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 46, 47, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 48, 57, 46, 48, 57, 48, 57, 
	46, 48, 57, 48, 57, 0, 32, 47, 
	9, 13, 48, 57, 0, 32, 46, 47, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 0, 32, 46, 47, 58, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	46, 47, 58, 9, 13, 48, 57, 46, 
	48, 57, 0, 32, 47, 58, 9, 13, 
	0, 32, 47, 58, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 47, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	0, 32, 47, 58, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 47, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 47, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 46, 47, 9, 
	13, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 47, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 46, 47, 9, 
	13, 48, 57, 0, 32, 47, 9, 13, 
	0, 32, 47, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 47, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	47, 9, 13, 48, 57, 65, 70, 97, 
	102, 58, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 58, 48, 
	57, 65, 70, 97, 102, 58, 58, 48, 
	57, 65, 70, 97, 102, 46, 47, 58, 
	93, 48, 57, 65, 70, 97, 102, 48, 
	57, 46, 48, 57, 48, 57, 46, 48, 
	57, 48, 57, 47, 93, 48, 57, 48, 
	57, 93, 48, 57, 0, 32, 58, 9, 
	13, 48, 57, 0, 32, 9, 13, 48, 
	57, 46, 47, 58, 93, 48, 57, 65, 
	70, 97, 102, 46, 47, 58, 93, 48, 
	57, 65, 70, 97, 102, 46, 47, 58, 
	93, 48, 57, 46, 48, 57, 47, 58, 
	93, 47, 58, 93, 48, 57, 65, 70, 
	97, 102, 47, 58, 93, 48, 57, 65, 
	70, 97, 102, 47, 93, 48, 57, 65, 
	70, 97, 102, 46, 47, 58, 93, 48, 
	57, 65, 70, 97, 102, 48, 57, 46, 
	48, 57, 48, 57, 46, 48, 57, 48, 
	57, 47, 93, 48, 57, 46, 47, 58, 
	93, 48, 57, 65, 70, 97, 102, 46, 
	47, 58, 93, 48, 57, 65, 70, 97, 
	102, 46, 47, 58, 93, 48, 57, 46, 
	48, 57, 47, 58, 93, 47, 58, 93, 
	48, 57, 65, 70, 97, 102, 47, 58, 
	93, 48, 57, 65, 70, 97, 102, 47, 
	58, 93, 48, 57, 65, 70, 97, 102, 
	47, 58, 93, 48, 57, 65, 70, 97, 
	102, 58, 48, 57, 65, 70, 97, 102, 
	46, 47, 93, 48, 57, 65, 70, 97, 
	102, 46, 47, 93, 48, 57, 65, 70, 
	97, 102, 46, 47, 93, 48, 57, 65, 
	70, 97, 102, 46, 47, 93, 48, 57, 
	47, 93, 47, 93, 48, 57, 65, 70, 
	97, 102, 47, 93, 48, 57, 65, 70, 
	97, 102, 47, 93, 48, 57, 65, 70, 
	97, 102, 58, 91, 48, 57, 65, 70, 
	97, 102, 58, 48, 57, 65, 70, 97, 
	102, 58, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 58, 
	58, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 58, 9, 13, 48, 57, 65, 
	70, 97, 102, 48, 57, 46, 48, 57, 
	48, 57, 46, 48, 57, 48, 57, 0, 
	32, 9, 13, 48, 57, 0, 32, 46, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 0, 32, 46, 58, 9, 13, 48, 
	57, 65, 70, 97, 102, 0, 32, 46, 
	58, 9, 13, 48, 57, 46, 48, 57, 
	0, 32, 58, 9, 13, 0, 32, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	0, 32, 58, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 9, 13, 48, 
	57, 65, 70, 97, 102, 0, 32, 46, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 48, 57, 46, 48, 57, 48, 57, 
	46, 48, 57, 48, 57, 0, 32, 9, 
	13, 48, 57, 0, 32, 46, 58, 9, 
	13, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 58, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 46, 58, 9, 
	13, 48, 57, 46, 48, 57, 0, 32, 
	58, 9, 13, 0, 32, 58, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 0, 32, 58, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 58, 9, 
	13, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	46, 9, 13, 48, 57, 65, 70, 97, 
	102, 0, 32, 46, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 46, 9, 
	13, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 9, 13, 48, 57, 0, 32, 
	9, 13, 0, 32, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 58, 48, 
	57, 65, 70, 97, 102, 58, 48, 57, 
	65, 70, 97, 102, 58, 58, 48, 57, 
	65, 70, 97, 102, 46, 58, 93, 48, 
	57, 65, 70, 97, 102, 48, 57, 46, 
	48, 57, 48, 57, 46, 48, 57, 48, 
	57, 93, 48, 57, 0, 32, 9, 13, 
	46, 58, 93, 48, 57, 65, 70, 97, 
	102, 46, 58, 93, 48, 57, 65, 70, 
	97, 102, 46, 58, 93, 48, 57, 46, 
	48, 57, 58, 93, 58, 93, 48, 57, 
	65, 70, 97, 102, 58, 93, 48, 57, 
	65, 70, 97, 102, 93, 48, 57, 65, 
	70, 97, 102, 46, 58, 93, 48, 57, 
	65, 70, 97, 102, 48, 57, 46, 48, 
	57, 48, 57, 46, 48, 57, 48, 57, 
	93, 48, 57, 46, 58, 93, 48, 57, 
	65, 70, 97, 102, 46, 58, 93, 48, 
	57, 65, 70, 97, 102, 46, 58, 93, 
	48, 57, 46, 48, 57, 58, 93, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 93, 93, 48, 57, 65, 70, 
	97, 102, 93, 48, 57, 65, 70, 97, 
	102, 93, 48, 57, 65, 70, 97, 102, 
	58, 91, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 58, 48, 
	57, 65, 70, 97, 102, 58, 58, 48, 
	57, 65, 70, 97, 102, 0, 32, 46, 
	47, 58, 9, 13, 48, 57, 65, 70, 
	97, 102, 48, 57, 46, 48, 57, 48, 
	57, 46, 48, 57, 48, 57, 0, 32, 
	47, 9, 13, 48, 57, 48, 57, 0, 
	32, 9, 13, 48, 57, 0, 32, 46, 
	47, 58, 9, 13, 48, 57, 65, 70, 
	97, 102, 0, 32, 46, 47, 58, 9, 
	13, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 47, 58, 9, 13, 48, 57, 
	46, 48, 57, 0, 32, 47, 58, 9, 
	13, 0, 32, 47, 58, 9, 13, 48, 
	57, 65, 70, 97, 102, 0, 32, 47, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 0, 32, 47, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 46, 47, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 48, 57, 46, 48, 57, 48, 57, 
	46, 48, 57, 48, 57, 0, 32, 47, 
	9, 13, 48, 57, 0, 32, 46, 47, 
	58, 9, 13, 48, 57, 65, 70, 97, 
	102, 0, 32, 46, 47, 58, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	46, 47, 58, 9, 13, 48, 57, 46, 
	48, 57, 0, 32, 47, 58, 9, 13, 
	0, 32, 47, 58, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 47, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	0, 32, 47, 58, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 47, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 47, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 46, 47, 9, 
	13, 48, 57, 65, 70, 97, 102, 0, 
	32, 46, 47, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 46, 47, 9, 
	13, 48, 57, 0, 32, 47, 9, 13, 
	0, 32, 47, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 47, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	47, 9, 13, 48, 57, 65, 70, 97, 
	102, 58, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 58, 48, 
	57, 65, 70, 97, 102, 58, 58, 48, 
	57, 65, 70, 97, 102, 46, 47, 58, 
	93, 48, 57, 65, 70, 97, 102, 48, 
	57, 46, 48, 57, 48, 57, 46, 48, 
	57, 48, 57, 47, 93, 48, 57, 48, 
	57, 93, 48, 57, 0, 32, 9, 13, 
	46, 47, 58, 93, 48, 57, 65, 70, 
	97, 102, 46, 47, 58, 93, 48, 57, 
	65, 70, 97, 102, 46, 47, 58, 93, 
	48, 57, 46, 48, 57, 47, 58, 93, 
	47, 58, 93, 48, 57, 65, 70, 97, 
	102, 47, 58, 93, 48, 57, 65, 70, 
	97, 102, 47, 93, 48, 57, 65, 70, 
	97, 102, 46, 47, 58, 93, 48, 57, 
	65, 70, 97, 102, 48, 57, 46, 48, 
	57, 48, 57, 46, 48, 57, 48, 57, 
	47, 93, 48, 57, 46, 47, 58, 93, 
	48, 57, 65, 70, 97, 102, 46, 47, 
	58, 93, 48, 57, 65, 70, 97, 102, 
	46, 47, 58, 93, 48, 57, 46, 48, 
	57, 47, 58, 93, 47, 58, 93, 48, 
	57, 65, 70, 97, 102, 47, 58, 93, 
	48, 57, 65, 70, 97, 102, 47, 58, 
	93, 48, 57, 65, 70, 97, 102, 47, 
	58, 93, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 46, 
	47, 93, 48, 57, 65, 70, 97, 102, 
	46, 47, 93, 48, 57, 65, 70, 97, 
	102, 46, 47, 93, 48, 57, 65, 70, 
	97, 102, 46, 47, 93, 48, 57, 47, 
	93, 47, 93, 48, 57, 65, 70, 97, 
	102, 47, 93, 48, 57, 65, 70, 97, 
	102, 47, 93, 48, 57, 65, 70, 97, 
	102, 58, 91, 48, 57, 65, 70, 97, 
	102, 58, 48, 57, 65, 70, 97, 102, 
	58, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 58, 58, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	46, 58, 9, 13, 48, 57, 65, 70, 
	97, 102, 48, 57, 46, 48, 57, 48, 
	57, 46, 48, 57, 48, 57, 0, 32, 
	9, 13, 48, 57, 0, 32, 46, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	0, 32, 46, 58, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 46, 58, 
	9, 13, 48, 57, 46, 48, 57, 0, 
	32, 58, 9, 13, 0, 32, 58, 9, 
	13, 48, 57, 65, 70, 97, 102, 0, 
	32, 58, 9, 13, 48, 57, 65, 70, 
	97, 102, 0, 32, 9, 13, 48, 57, 
	65, 70, 97, 102, 0, 32, 46, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	48, 57, 46, 48, 57, 48, 57, 46, 
	48, 57, 48, 57, 0, 32, 9, 13, 
	48, 57, 0, 32, 46, 58, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	46, 58, 9, 13, 48, 57, 65, 70, 
	97, 102, 0, 32, 46, 58, 9, 13, 
	48, 57, 46, 48, 57, 0, 32, 58, 
	9, 13, 0, 32, 58, 9, 13, 48, 
	57, 65, 70, 97, 102, 0, 32, 58, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	0, 32, 58, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 58, 9, 13, 
	48, 57, 65, 70, 97, 102, 58, 48, 
	57, 65, 70, 97, 102, 0, 32, 46, 
	9, 13, 48, 57, 65, 70, 97, 102, 
	0, 32, 46, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 46, 9, 13, 
	48, 57, 65, 70, 97, 102, 0, 32, 
	46, 9, 13, 48, 57, 0, 32, 9, 
	13, 0, 32, 9, 13, 48, 57, 65, 
	70, 97, 102, 0, 32, 9, 13, 48, 
	57, 65, 70, 97, 102, 0, 32, 9, 
	13, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 58, 48, 
	57, 65, 70, 97, 102, 58, 48, 57, 
	65, 70, 97, 102, 58, 48, 57, 65, 
	70, 97, 102, 58, 58, 48, 57, 65, 
	70, 97, 102, 46, 58, 93, 48, 57, 
	65, 70, 97, 102, 48, 57, 46, 48, 
	57, 48, 57, 46, 48, 57, 48, 57, 
	93, 48, 57, 0, 32, 58, 9, 13, 
	48, 57, 0, 32, 9, 13, 48, 57, 
	46, 58, 93, 48, 57, 65, 70, 97, 
	102, 46, 58, 93, 48, 57, 65, 70, 
	97, 102, 46, 58, 93, 48, 57, 46, 
	48, 57, 58, 93, 58, 93, 48, 57, 
	65, 70, 97, 102, 58, 93, 48, 57, 
	65, 70, 97, 102, 93, 48, 57, 65, 
	70, 97, 102, 46, 58, 93, 48, 57, 
	65, 70, 97, 102, 48, 57, 46, 48, 
	57, 48, 57, 46, 48, 57, 48, 57, 
	93, 48, 57, 46, 58, 93, 48, 57, 
	65, 70, 97, 102, 46, 58, 93, 48, 
	57, 65, 70, 97, 102, 46, 58, 93, 
	48, 57, 46, 48, 57, 58, 93, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	93, 48, 57, 65, 70, 97, 102, 58, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 65, 70, 97, 102, 46, 93, 
	48, 57, 93, 93, 48, 57, 65, 70, 
	97, 102, 93, 48, 57, 65, 70, 97, 
	102, 93, 48, 57, 65, 70, 97, 102, 
	0
};

static const char _ipv6_parser_single_lengths[] = {
	0, 2, 1, 1, 1, 1, 1, 5, 
	0, 1, 0, 1, 0, 3, 0, 2, 
	5, 5, 5, 1, 4, 4, 4, 3, 
	5, 0, 1, 0, 1, 0, 3, 5, 
	5, 5, 1, 4, 4, 4, 4, 4, 
	1, 4, 4, 4, 4, 3, 3, 3, 
	3, 1, 1, 1, 1, 1, 1, 4, 
	0, 1, 0, 1, 0, 2, 0, 1, 
	3, 0, 2, 4, 4, 4, 1, 3, 
	3, 3, 2, 4, 0, 1, 0, 1, 
	0, 2, 4, 4, 4, 1, 3, 3, 
	3, 3, 3, 1, 3, 3, 3, 3, 
	2, 2, 2, 2, 2, 1, 1, 1, 
	1, 1, 4, 0, 1, 0, 1, 0, 
	2, 4, 4, 4, 1, 3, 3, 3, 
	2, 4, 0, 1, 0, 1, 0, 2, 
	4, 4, 4, 1, 3, 3, 3, 3, 
	3, 1, 3, 3, 3, 3, 2, 2, 
	2, 2, 1, 1, 1, 1, 1, 1, 
	3, 0, 1, 0, 1, 0, 1, 2, 
	3, 3, 3, 1, 2, 2, 2, 1, 
	3, 0, 1, 0, 1, 0, 1, 3, 
	3, 3, 1, 2, 2, 2, 2, 2, 
	1, 2, 2, 2, 2, 1, 1, 1, 
	1, 2, 1, 1, 1, 1, 1, 5, 
	0, 1, 0, 1, 0, 3, 0, 2, 
	5, 5, 5, 1, 4, 4, 4, 3, 
	5, 0, 1, 0, 1, 0, 3, 5, 
	5, 5, 1, 4, 4, 4, 4, 4, 
	1, 4, 4, 4, 4, 3, 3, 3, 
	3, 1, 1, 1, 1, 1, 1, 4, 
	0, 1, 0, 1, 0, 2, 0, 1, 
	2, 4, 4, 4, 1, 3, 3, 3, 
	2, 4, 0, 1, 0, 1, 0, 2, 
	4, 4, 4, 1, 3, 3, 3, 3, 
	3, 1, 3, 3, 3, 3, 2, 2, 
	2, 2, 2, 1, 1, 1, 1, 1, 
	4, 0, 1, 0, 1, 0, 2, 4, 
	4, 4, 1, 3, 3, 3, 2, 4, 
	0, 1, 0, 1, 0, 2, 4, 4, 
	4, 1, 3, 3, 3, 3, 3, 1, 
	3, 3, 3, 3, 2, 2, 2, 2, 
	1, 1, 1, 1, 1, 1, 3, 0, 
	1, 0, 1, 0, 1, 3, 0, 2, 
	3, 3, 3, 1, 2, 2, 2, 1, 
	3, 0, 1, 0, 1, 0, 1, 3, 
	3, 3, 1, 2, 2, 2, 2, 2, 
	1, 2, 2, 2, 2, 1, 1, 1, 
	1, 0, 0, 0, 0
};

static const char _ipv6_parser_range_lengths[] = {
	0, 3, 3, 3, 3, 0, 3, 4, 
	1, 1, 1, 1, 1, 2, 1, 2, 
	4, 4, 2, 1, 1, 4, 4, 4, 
	4, 1, 1, 1, 1, 1, 2, 4, 
	4, 2, 1, 1, 4, 4, 4, 4, 
	3, 4, 4, 4, 2, 1, 4, 4, 
	4, 3, 3, 3, 3, 0, 3, 3, 
	1, 1, 1, 1, 1, 1, 1, 1, 
	1, 1, 2, 3, 3, 1, 1, 0, 
	3, 3, 3, 3, 1, 1, 1, 1, 
	1, 1, 3, 3, 1, 1, 0, 3, 
	3, 3, 3, 3, 3, 3, 3, 1, 
	0, 3, 3, 3, 3, 3, 3, 3, 
	0, 3, 4, 1, 1, 1, 1, 1, 
	2, 4, 4, 2, 1, 1, 4, 4, 
	4, 4, 1, 1, 1, 1, 1, 2, 
	4, 4, 2, 1, 1, 4, 4, 4, 
	4, 3, 4, 4, 4, 2, 1, 4, 
	4, 4, 3, 3, 3, 3, 0, 3, 
	3, 1, 1, 1, 1, 1, 1, 1, 
	3, 3, 1, 1, 0, 3, 3, 3, 
	3, 1, 1, 1, 1, 1, 1, 3, 
	3, 1, 1, 0, 3, 3, 3, 3, 
	3, 3, 3, 3, 1, 0, 3, 3, 
	3, 3, 3, 3, 3, 0, 3, 4, 
	1, 1, 1, 1, 1, 2, 1, 2, 
	4, 4, 2, 1, 1, 4, 4, 4, 
	4, 1, 1, 1, 1, 1, 2, 4, 
	4, 2, 1, 1, 4, 4, 4, 4, 
	3, 4, 4, 4, 2, 1, 4, 4, 
	4, 3, 3, 3, 3, 0, 3, 3, 
	1, 1, 1, 1, 1, 1, 1, 1, 
	1, 3, 3, 1, 1, 0, 3, 3, 
	3, 3, 1, 1, 1, 1, 1, 1, 
	3, 3, 1, 1, 0, 3, 3, 3, 
	3, 3, 3, 3, 3, 1, 0, 3, 
	3, 3, 3, 3, 3, 3, 0, 3, 
	4, 1, 1, 1, 1, 1, 2, 4, 
	4, 2, 1, 1, 4, 4, 4, 4, 
	1, 1, 1, 1, 1, 2, 4, 4, 
	2, 1, 1, 4, 4, 4, 4, 3, 
	4, 4, 4, 2, 1, 4, 4, 4, 
	3, 3, 3, 3, 0, 3, 3, 1, 
	1, 1, 1, 1, 1, 1, 1, 2, 
	3, 3, 1, 1, 0, 3, 3, 3, 
	3, 1, 1, 1, 1, 1, 1, 3, 
	3, 1, 1, 0, 3, 3, 3, 3, 
	3, 3, 3, 3, 1, 0, 3, 3, 
	3, 0, 0, 0, 0
};

static const short _ipv6_parser_index_offsets[] = {
	0, 0, 6, 11, 16, 21, 23, 28, 
	38, 40, 43, 45, 48, 50, 56, 58, 
	63, 73, 83, 91, 94, 100, 109, 118, 
	126, 136, 138, 141, 143, 146, 148, 154, 
	164, 174, 182, 185, 191, 200, 209, 218, 
	227, 232, 241, 250, 259, 266, 271, 279, 
	287, 295, 300, 305, 310, 315, 317, 322, 
	330, 332, 335, 337, 340, 342, 346, 348, 
	351, 356, 358, 363, 371, 379, 385, 388, 
	392, 399, 406, 412, 420, 422, 425, 427, 
	430, 432, 436, 444, 452, 458, 461, 465, 
	472, 479, 486, 493, 498, 505, 512, 519, 
	524, 527, 533, 539, 545, 551, 556, 561, 
	566, 568, 573, 582, 584, 587, 589, 592, 
	594, 599, 608, 617, 624, 627, 632, 640, 
	648, 655, 664, 666, 669, 671, 674, 676, 
	681, 690, 699, 706, 709, 714, 722, 730, 
	738, 746, 751, 759, 767, 775, 781, 785, 
	792, 799, 806, 811, 816, 821, 826, 828, 
	833, 840, 842, 845, 847, 850, 852, 855, 
	859, 866, 873, 878, 881, 884, 890, 896, 
	901, 908, 910, 913, 915, 918, 920, 923, 
	930, 937, 942, 945, 948, 954, 960, 966, 
	972, 977, 983, 989, 995, 999, 1001, 1006, 
	1011, 1016, 1022, 1027, 1032, 1037, 1039, 1044, 
	1054, 1056, 1059, 1061, 1064, 1066, 1072, 1074, 
	1079, 1089, 1099, 1107, 1110, 1116, 1125, 1134, 
	1142, 1152, 1154, 1157, 1159, 1162, 1164, 1170, 
	1180, 1190, 1198, 1201, 1207, 1216, 1225, 1234, 
	1243, 1248, 1257, 1266, 1275, 1282, 1287, 1295, 
	1303, 1311, 1316, 1321, 1326, 1331, 1333, 1338, 
	1346, 1348, 1351, 1353, 1356, 1358, 1362, 1364, 
	1367, 1371, 1379, 1387, 1393, 1396, 1400, 1407, 
	1414, 1420, 1428, 1430, 1433, 1435, 1438, 1440, 
	1444, 1452, 1460, 1466, 1469, 1473, 1480, 1487, 
	1494, 1501, 1506, 1513, 1520, 1527, 1532, 1535, 
	1541, 1547, 1553, 1559, 1564, 1569, 1574, 1576, 
	1581, 1590, 1592, 1595, 1597, 1600, 1602, 1607, 
	1616, 1625, 1632, 1635, 1640, 1648, 1656, 1663, 
	1672, 1674, 1677, 1679, 1682, 1684, 1689, 1698, 
	1707, 1714, 1717, 1722, 1730, 1738, 1746, 1754, 
	1759, 1767, 1775, 1783, 1789, 1793, 1800, 1807, 
	1814, 1819, 1824, 1829, 1834, 1836, 1841, 1848, 
	1850, 1853, 1855, 1858, 1860, 1863, 1868, 1870, 
	1875, 1882, 1889, 1894, 1897, 1900, 1906, 1912, 
	1917, 1924, 1926, 1929, 1931, 1934, 1936, 1939, 
	1946, 1953, 1958, 1961, 1964, 1970, 1976, 1982, 
	1988, 1993, 1999, 2005, 2011, 2015, 2017, 2022, 
	2027, 2032, 2033, 2034, 2035
};

static const short _ipv6_parser_indicies[] = {
	2, 3, 0, 0, 0, 1, 5, 4, 
	4, 4, 1, 5, 6, 6, 6, 1, 
	5, 7, 7, 7, 1, 5, 1, 9, 
	8, 10, 10, 1, 11, 11, 12, 13, 
	5, 11, 14, 15, 15, 1, 16, 1, 
	17, 18, 1, 19, 1, 20, 21, 1, 
	22, 1, 23, 23, 24, 23, 25, 1, 
	26, 1, 27, 27, 27, 28, 1, 11, 
	11, 12, 13, 5, 11, 29, 30, 30, 
	1, 11, 11, 12, 13, 5, 11, 31, 
	32, 32, 1, 11, 11, 12, 13, 5, 
	11, 33, 1, 12, 33, 1, 11, 11, 
	13, 5, 11, 1, 11, 11, 13, 5, 
	11, 32, 32, 32, 1, 11, 11, 13, 
	5, 11, 30, 30, 30, 1, 34, 34, 
	35, 34, 36, 37, 37, 1, 38, 38, 
	39, 40, 42, 38, 41, 43, 43, 1, 
	44, 1, 45, 46, 1, 47, 1, 48, 
	49, 1, 50, 1, 51, 51, 52, 51, 
	53, 1, 38, 38, 39, 40, 42, 38, 
	54, 55, 55, 1, 38, 38, 39, 40, 
	42, 38, 56, 57, 57, 1, 38, 38, 
	39, 40, 42, 38, 58, 1, 39, 58, 
	1, 38, 38, 40, 42, 38, 1, 38, 
	38, 40, 42, 38, 57, 57, 57, 1, 
	38, 38, 40, 42, 38, 55, 55, 55, 
	1, 38, 38, 40, 42, 38, 43, 43, 
	43, 1, 11, 11, 13, 5, 11, 15, 
	15, 15, 1, 9, 59, 60, 60, 1, 
	11, 11, 12, 13, 11, 61, 62, 62, 
	1, 11, 11, 12, 13, 11, 63, 64, 
	64, 1, 11, 11, 12, 13, 11, 65, 
	66, 66, 1, 11, 11, 12, 13, 11, 
	33, 1, 11, 11, 13, 11, 1, 11, 
	11, 13, 11, 66, 66, 66, 1, 11, 
	11, 13, 11, 64, 64, 64, 1, 11, 
	11, 13, 11, 62, 62, 62, 1, 68, 
	67, 67, 67, 1, 70, 69, 69, 69, 
	1, 70, 71, 71, 71, 1, 70, 72, 
	72, 72, 1, 70, 1, 74, 73, 75, 
	75, 1, 76, 77, 70, 80, 78, 79, 
	79, 1, 81, 1, 82, 83, 1, 84, 
	1, 85, 86, 1, 87, 1, 88, 90, 
	89, 1, 91, 1, 93, 92, 1, 34, 
	34, 94, 34, 1, 95, 1, 96, 96, 
	96, 97, 1, 76, 77, 70, 80, 98, 
	99, 99, 1, 76, 77, 70, 80, 100, 
	101, 101, 1, 76, 77, 70, 80, 102, 
	1, 76, 102, 1, 77, 70, 80, 1, 
	77, 70, 80, 101, 101, 101, 1, 77, 
	70, 80, 99, 99, 99, 1, 103, 106, 
	104, 105, 105, 1, 107, 108, 110, 112, 
	109, 111, 111, 1, 113, 1, 114, 115, 
	1, 116, 1, 117, 118, 1, 119, 1, 
	120, 122, 121, 1, 107, 108, 110, 112, 
	123, 124, 124, 1, 107, 108, 110, 112, 
	125, 126, 126, 1, 107, 108, 110, 112, 
	127, 1, 107, 127, 1, 108, 110, 112, 
	1, 108, 110, 112, 126, 126, 126, 1, 
	108, 110, 112, 124, 124, 124, 1, 108, 
	110, 112, 111, 111, 111, 1, 77, 70, 
	80, 79, 79, 79, 1, 74, 128, 129, 
	129, 1, 76, 77, 80, 130, 131, 131, 
	1, 76, 77, 80, 132, 133, 133, 1, 
	76, 77, 80, 134, 135, 135, 1, 76, 
	77, 80, 102, 1, 77, 80, 1, 77, 
	80, 135, 135, 135, 1, 77, 80, 133, 
	133, 133, 1, 77, 80, 131, 131, 131, 
	1, 137, 138, 136, 136, 136, 1, 140, 
	139, 139, 139, 1, 140, 141, 141, 141, 
	1, 140, 142, 142, 142, 1, 140, 1, 
	144, 143, 145, 145, 1, 146, 146, 147, 
	140, 146, 148, 149, 149, 1, 150, 1, 
	151, 152, 1, 153, 1, 154, 155, 1, 
	156, 1, 157, 157, 157, 158, 1, 146, 
	146, 147, 140, 146, 159, 160, 160, 1, 
	146, 146, 147, 140, 146, 161, 162, 162, 
	1, 146, 146, 147, 140, 146, 163, 1, 
	147, 163, 1, 146, 146, 140, 146, 1, 
	146, 146, 140, 146, 162, 162, 162, 1, 
	146, 146, 140, 146, 160, 160, 160, 1, 
	164, 164, 164, 165, 166, 166, 1, 167, 
	167, 168, 170, 167, 169, 171, 171, 1, 
	172, 1, 173, 174, 1, 175, 1, 176, 
	177, 1, 178, 1, 179, 179, 179, 180, 
	1, 167, 167, 168, 170, 167, 181, 182, 
	182, 1, 167, 167, 168, 170, 167, 183, 
	184, 184, 1, 167, 167, 168, 170, 167, 
	185, 1, 168, 185, 1, 167, 167, 170, 
	167, 1, 167, 167, 170, 167, 184, 184, 
	184, 1, 167, 167, 170, 167, 182, 182, 
	182, 1, 167, 167, 170, 167, 171, 171, 
	171, 1, 146, 146, 140, 146, 149, 149, 
	149, 1, 144, 186, 187, 187, 1, 146, 
	146, 147, 146, 188, 189, 189, 1, 146, 
	146, 147, 146, 190, 191, 191, 1, 146, 
	146, 147, 146, 192, 193, 193, 1, 146, 
	146, 147, 146, 163, 1, 146, 146, 146, 
	1, 146, 146, 146, 193, 193, 193, 1, 
	146, 146, 146, 191, 191, 191, 1, 146, 
	146, 146, 189, 189, 189, 1, 195, 194, 
	194, 194, 1, 197, 196, 196, 196, 1, 
	197, 198, 198, 198, 1, 197, 199, 199, 
	199, 1, 197, 1, 201, 200, 202, 202, 
	1, 203, 197, 206, 204, 205, 205, 1, 
	207, 1, 208, 209, 1, 210, 1, 211, 
	212, 1, 213, 1, 215, 214, 1, 164, 
	164, 164, 1, 203, 197, 206, 216, 217, 
	217, 1, 203, 197, 206, 218, 219, 219, 
	1, 203, 197, 206, 220, 1, 203, 220, 
	1, 197, 206, 1, 197, 206, 219, 219, 
	219, 1, 197, 206, 217, 217, 217, 1, 
	223, 221, 222, 222, 1, 224, 226, 228, 
	225, 227, 227, 1, 229, 1, 230, 231, 
	1, 232, 1, 233, 234, 1, 235, 1, 
	237, 236, 1, 224, 226, 228, 238, 239, 
	239, 1, 224, 226, 228, 240, 241, 241, 
	1, 224, 226, 228, 242, 1, 224, 242, 
	1, 226, 228, 1, 226, 228, 241, 241, 
	241, 1, 226, 228, 239, 239, 239, 1, 
	226, 228, 227, 227, 227, 1, 197, 206, 
	205, 205, 205, 1, 201, 243, 244, 244, 
	1, 203, 206, 245, 246, 246, 1, 203, 
	206, 247, 248, 248, 1, 203, 206, 249, 
	250, 250, 1, 203, 206, 220, 1, 206, 
	1, 206, 250, 250, 250, 1, 206, 248, 
	248, 248, 1, 206, 246, 246, 246, 1, 
	252, 253, 251, 251, 251, 1, 255, 254, 
	254, 254, 1, 255, 256, 256, 256, 1, 
	255, 257, 257, 257, 1, 255, 1, 259, 
	258, 260, 260, 1, 261, 261, 262, 263, 
	255, 261, 264, 265, 265, 1, 266, 1, 
	267, 268, 1, 269, 1, 270, 271, 1, 
	272, 1, 273, 273, 274, 273, 275, 1, 
	276, 1, 277, 277, 277, 278, 1, 261, 
	261, 262, 263, 255, 261, 279, 280, 280, 
	1, 261, 261, 262, 263, 255, 261, 281, 
	282, 282, 1, 261, 261, 262, 263, 255, 
	261, 283, 1, 262, 283, 1, 261, 261, 
	263, 255, 261, 1, 261, 261, 263, 255, 
	261, 282, 282, 282, 1, 261, 261, 263, 
	255, 261, 280, 280, 280, 1, 284, 284, 
	285, 284, 286, 287, 287, 1, 288, 288, 
	289, 290, 292, 288, 291, 293, 293, 1, 
	294, 1, 295, 296, 1, 297, 1, 298, 
	299, 1, 300, 1, 301, 301, 302, 301, 
	303, 1, 288, 288, 289, 290, 292, 288, 
	304, 305, 305, 1, 288, 288, 289, 290, 
	292, 288, 306, 307, 307, 1, 288, 288, 
	289, 290, 292, 288, 308, 1, 289, 308, 
	1, 288, 288, 290, 292, 288, 1, 288, 
	288, 290, 292, 288, 307, 307, 307, 1, 
	288, 288, 290, 292, 288, 305, 305, 305, 
	1, 288, 288, 290, 292, 288, 293, 293, 
	293, 1, 261, 261, 263, 255, 261, 265, 
	265, 265, 1, 259, 309, 310, 310, 1, 
	261, 261, 262, 263, 261, 311, 312, 312, 
	1, 261, 261, 262, 263, 261, 313, 314, 
	314, 1, 261, 261, 262, 263, 261, 315, 
	316, 316, 1, 261, 261, 262, 263, 261, 
	283, 1, 261, 261, 263, 261, 1, 261, 
	261, 263, 261, 316, 316, 316, 1, 261, 
	261, 263, 261, 314, 314, 314, 1, 261, 
	261, 263, 261, 312, 312, 312, 1, 318, 
	317, 317, 317, 1, 320, 319, 319, 319, 
	1, 320, 321, 321, 321, 1, 320, 322, 
	322, 322, 1, 320, 1, 324, 323, 325, 
	325, 1, 326, 327, 320, 330, 328, 329, 
	329, 1, 331, 1, 332, 333, 1, 334, 
	1, 335, 336, 1, 337, 1, 338, 340, 
	339, 1, 341, 1, 343, 342, 1, 284, 
	284, 284, 1, 326, 327, 320, 330, 344, 
	345, 345, 1, 326, 327, 320, 330, 346, 
	347, 347, 1, 326, 327, 320, 330, 348, 
	1, 326, 348, 1, 327, 320, 330, 1, 
	327, 320, 330, 347, 347, 347, 1, 327, 
	320, 330, 345, 345, 345, 1, 349, 352, 
	350, 351, 351, 1, 353, 354, 356, 358, 
	355, 357, 357, 1, 359, 1, 360, 361, 
	1, 362, 1, 363, 364, 1, 365, 1, 
	366, 368, 367, 1, 353, 354, 356, 358, 
	369, 370, 370, 1, 353, 354, 356, 358, 
	371, 372, 372, 1, 353, 354, 356, 358, 
	373, 1, 353, 373, 1, 354, 356, 358, 
	1, 354, 356, 358, 372, 372, 372, 1, 
	354, 356, 358, 370, 370, 370, 1, 354, 
	356, 358, 357, 357, 357, 1, 327, 320, 
	330, 329, 329, 329, 1, 324, 374, 375, 
	375, 1, 326, 327, 330, 376, 377, 377, 
	1, 326, 327, 330, 378, 379, 379, 1, 
	326, 327, 330, 380, 381, 381, 1, 326, 
	327, 330, 348, 1, 327, 330, 1, 327, 
	330, 381, 381, 381, 1, 327, 330, 379, 
	379, 379, 1, 327, 330, 377, 377, 377, 
	1, 383, 384, 382, 382, 382, 1, 386, 
	385, 385, 385, 1, 386, 387, 387, 387, 
	1, 386, 388, 388, 388, 1, 386, 1, 
	390, 389, 391, 391, 1, 392, 392, 393, 
	386, 392, 394, 395, 395, 1, 396, 1, 
	397, 398, 1, 399, 1, 400, 401, 1, 
	402, 1, 403, 403, 403, 404, 1, 392, 
	392, 393, 386, 392, 405, 406, 406, 1, 
	392, 392, 393, 386, 392, 407, 408, 408, 
	1, 392, 392, 393, 386, 392, 409, 1, 
	393, 409, 1, 392, 392, 386, 392, 1, 
	392, 392, 386, 392, 408, 408, 408, 1, 
	392, 392, 386, 392, 406, 406, 406, 1, 
	410, 410, 410, 411, 412, 412, 1, 413, 
	413, 414, 416, 413, 415, 417, 417, 1, 
	418, 1, 419, 420, 1, 421, 1, 422, 
	423, 1, 424, 1, 425, 425, 425, 426, 
	1, 413, 413, 414, 416, 413, 427, 428, 
	428, 1, 413, 413, 414, 416, 413, 429, 
	430, 430, 1, 413, 413, 414, 416, 413, 
	431, 1, 414, 431, 1, 413, 413, 416, 
	413, 1, 413, 413, 416, 413, 430, 430, 
	430, 1, 413, 413, 416, 413, 428, 428, 
	428, 1, 413, 413, 416, 413, 417, 417, 
	417, 1, 392, 392, 386, 392, 395, 395, 
	395, 1, 390, 432, 433, 433, 1, 392, 
	392, 393, 392, 434, 435, 435, 1, 392, 
	392, 393, 392, 436, 437, 437, 1, 392, 
	392, 393, 392, 438, 439, 439, 1, 392, 
	392, 393, 392, 409, 1, 392, 392, 392, 
	1, 392, 392, 392, 439, 439, 439, 1, 
	392, 392, 392, 437, 437, 437, 1, 392, 
	392, 392, 435, 435, 435, 1, 441, 440, 
	440, 440, 1, 443, 442, 442, 442, 1, 
	443, 444, 444, 444, 1, 443, 445, 445, 
	445, 1, 443, 1, 447, 446, 448, 448, 
	1, 449, 443, 452, 450, 451, 451, 1, 
	453, 1, 454, 455, 1, 456, 1, 457, 
	458, 1, 459, 1, 461, 460, 1, 410, 
	410, 462, 410, 1, 463, 1, 464, 464, 
	464, 465, 1, 449, 443, 452, 466, 467, 
	467, 1, 449, 443, 452, 468, 469, 469, 
	1, 449, 443, 452, 470, 1, 449, 470, 
	1, 443, 452, 1, 443, 452, 469, 469, 
	469, 1, 443, 452, 467, 467, 467, 1, 
	473, 471, 472, 472, 1, 474, 476, 478, 
	475, 477, 477, 1, 479, 1, 480, 481, 
	1, 482, 1, 483, 484, 1, 485, 1, 
	487, 486, 1, 474, 476, 478, 488, 489, 
	489, 1, 474, 476, 478, 490, 491, 491, 
	1, 474, 476, 478, 492, 1, 474, 492, 
	1, 476, 478, 1, 476, 478, 491, 491, 
	491, 1, 476, 478, 489, 489, 489, 1, 
	476, 478, 477, 477, 477, 1, 443, 452, 
	451, 451, 451, 1, 447, 493, 494, 494, 
	1, 449, 452, 495, 496, 496, 1, 449, 
	452, 497, 498, 498, 1, 449, 452, 499, 
	500, 500, 1, 449, 452, 470, 1, 452, 
	1, 452, 500, 500, 500, 1, 452, 498, 
	498, 498, 1, 452, 496, 496, 496, 1, 
	1, 1, 1, 1, 0
};

static const short _ipv6_parser_trans_targs[] = {
	2, 0, 40, 49, 3, 6, 4, 5, 
	7, 23, 39, 385, 8, 14, 16, 22, 
	9, 10, 9, 11, 12, 11, 13, 385, 
	14, 13, 15, 385, 15, 17, 21, 18, 
	20, 19, 385, 14, 24, 38, 385, 25, 
	14, 31, 23, 37, 26, 27, 26, 28, 
	29, 28, 30, 385, 14, 30, 32, 36, 
	33, 35, 34, 41, 48, 42, 47, 43, 
	46, 44, 45, 50, 91, 51, 54, 52, 
	53, 55, 74, 90, 56, 62, 67, 73, 
	64, 57, 58, 57, 59, 60, 59, 61, 
	62, 61, 64, 63, 63, 64, 65, 66, 
	385, 66, 68, 72, 69, 71, 70, 62, 
	75, 89, 64, 76, 62, 82, 74, 88, 
	64, 77, 78, 77, 79, 80, 79, 81, 
	62, 81, 64, 83, 87, 84, 86, 85, 
	92, 99, 93, 98, 94, 97, 95, 96, 
	101, 137, 146, 102, 105, 103, 104, 106, 
	120, 136, 386, 107, 113, 119, 108, 109, 
	108, 110, 111, 110, 112, 386, 112, 114, 
	118, 115, 117, 116, 386, 121, 135, 386, 
	122, 128, 120, 134, 123, 124, 123, 125, 
	126, 125, 127, 386, 127, 129, 133, 130, 
	132, 131, 138, 145, 139, 144, 140, 143, 
	141, 142, 147, 184, 148, 151, 149, 150, 
	152, 167, 183, 153, 160, 166, 159, 154, 
	155, 154, 156, 157, 156, 158, 158, 159, 
	161, 165, 162, 164, 163, 168, 182, 159, 
	169, 175, 167, 181, 159, 170, 171, 170, 
	172, 173, 172, 174, 174, 159, 176, 180, 
	177, 179, 178, 185, 192, 186, 191, 187, 
	190, 188, 189, 194, 232, 241, 195, 198, 
	196, 197, 199, 215, 231, 387, 200, 206, 
	208, 214, 201, 202, 201, 203, 204, 203, 
	205, 387, 206, 205, 207, 387, 207, 209, 
	213, 210, 212, 211, 387, 206, 216, 230, 
	387, 217, 206, 223, 215, 229, 218, 219, 
	218, 220, 221, 220, 222, 387, 206, 222, 
	224, 228, 225, 227, 226, 233, 240, 234, 
	239, 235, 238, 236, 237, 242, 281, 243, 
	246, 244, 245, 247, 264, 280, 248, 254, 
	257, 263, 256, 249, 250, 249, 251, 252, 
	251, 253, 254, 253, 256, 255, 255, 256, 
	258, 262, 259, 261, 260, 254, 265, 279, 
	256, 266, 254, 272, 264, 278, 256, 267, 
	268, 267, 269, 270, 269, 271, 254, 271, 
	256, 273, 277, 274, 276, 275, 282, 289, 
	283, 288, 284, 287, 285, 286, 291, 327, 
	336, 292, 295, 293, 294, 296, 310, 326, 
	388, 297, 303, 309, 298, 299, 298, 300, 
	301, 300, 302, 388, 302, 304, 308, 305, 
	307, 306, 388, 311, 325, 388, 312, 318, 
	310, 324, 313, 314, 313, 315, 316, 315, 
	317, 388, 317, 319, 323, 320, 322, 321, 
	328, 335, 329, 334, 330, 333, 331, 332, 
	337, 376, 338, 341, 339, 340, 342, 359, 
	375, 343, 352, 358, 349, 344, 345, 344, 
	346, 347, 346, 348, 348, 349, 350, 351, 
	388, 351, 353, 357, 354, 356, 355, 360, 
	374, 349, 361, 367, 359, 373, 349, 362, 
	363, 362, 364, 365, 364, 366, 366, 349, 
	368, 372, 369, 371, 370, 377, 384, 378, 
	383, 379, 382, 380, 381
};

static const char _ipv6_parser_trans_actions[] = {
	1, 0, 0, 0, 0, 2, 0, 0, 
	3, 4, 1, 5, 6, 2, 7, 0, 
	8, 6, 7, 8, 6, 7, 8, 9, 
	10, 7, 8, 11, 7, 7, 0, 7, 
	0, 7, 12, 0, 3, 1, 13, 6, 
	14, 7, 14, 0, 8, 6, 7, 8, 
	6, 7, 8, 15, 16, 7, 7, 0, 
	7, 0, 7, 3, 1, 7, 0, 7, 
	0, 7, 0, 1, 0, 0, 2, 0, 
	0, 3, 4, 1, 6, 2, 7, 0, 
	2, 8, 6, 7, 8, 6, 7, 8, 
	10, 7, 10, 8, 7, 17, 0, 8, 
	18, 7, 7, 0, 7, 0, 7, 0, 
	3, 1, 0, 6, 14, 7, 14, 0, 
	14, 8, 6, 7, 8, 6, 7, 8, 
	16, 7, 16, 7, 0, 7, 0, 7, 
	3, 1, 7, 0, 7, 0, 7, 0, 
	1, 0, 0, 0, 2, 0, 0, 3, 
	4, 1, 5, 6, 7, 0, 8, 6, 
	7, 8, 6, 7, 8, 9, 7, 7, 
	0, 7, 0, 7, 12, 3, 1, 13, 
	6, 7, 14, 0, 8, 6, 7, 8, 
	6, 7, 8, 15, 7, 7, 0, 7, 
	0, 7, 3, 1, 7, 0, 7, 0, 
	7, 0, 1, 0, 0, 2, 0, 0, 
	3, 4, 1, 6, 7, 0, 2, 8, 
	6, 7, 8, 6, 7, 8, 7, 10, 
	7, 0, 7, 0, 7, 3, 1, 0, 
	6, 7, 14, 0, 14, 8, 6, 7, 
	8, 6, 7, 8, 7, 16, 7, 0, 
	7, 0, 7, 3, 1, 7, 0, 7, 
	0, 7, 0, 1, 0, 0, 0, 2, 
	0, 0, 3, 4, 1, 5, 6, 2, 
	7, 0, 8, 6, 7, 8, 6, 7, 
	8, 9, 10, 7, 8, 11, 7, 7, 
	0, 7, 0, 7, 12, 0, 3, 1, 
	13, 6, 14, 7, 14, 0, 8, 6, 
	7, 8, 6, 7, 8, 15, 16, 7, 
	7, 0, 7, 0, 7, 3, 1, 7, 
	0, 7, 0, 7, 0, 1, 0, 0, 
	2, 0, 0, 3, 4, 1, 6, 2, 
	7, 0, 2, 8, 6, 7, 8, 6, 
	7, 8, 10, 7, 10, 8, 7, 17, 
	7, 0, 7, 0, 7, 0, 3, 1, 
	0, 6, 14, 7, 14, 0, 14, 8, 
	6, 7, 8, 6, 7, 8, 16, 7, 
	16, 7, 0, 7, 0, 7, 3, 1, 
	7, 0, 7, 0, 7, 0, 1, 0, 
	0, 0, 2, 0, 0, 3, 4, 1, 
	5, 6, 7, 0, 8, 6, 7, 8, 
	6, 7, 8, 9, 7, 7, 0, 7, 
	0, 7, 12, 3, 1, 13, 6, 7, 
	14, 0, 8, 6, 7, 8, 6, 7, 
	8, 15, 7, 7, 0, 7, 0, 7, 
	3, 1, 7, 0, 7, 0, 7, 0, 
	1, 0, 0, 2, 0, 0, 3, 4, 
	1, 6, 7, 0, 2, 8, 6, 7, 
	8, 6, 7, 8, 7, 10, 0, 8, 
	18, 7, 7, 0, 7, 0, 7, 3, 
	1, 0, 6, 7, 14, 0, 14, 8, 
	6, 7, 8, 6, 7, 8, 7, 16, 
	7, 0, 7, 0, 7, 3, 1, 7, 
	0, 7, 0, 7, 0
};

static const int ipv6_parser_start = 1;
static const int ipv6_parser_first_final = 385;
static const int ipv6_parser_error = 0;

static const int ipv6_parser_en_ipv6 = 100;
static const int ipv6_parser_en_ipv6_cidr = 193;
static const int ipv6_parser_en_ipv6_socket = 290;
static const int ipv6_parser_en_ipv6_socket_cidr = 1;

#line 112 "../../../src/common/ip_parsers.rl"


gboolean li_parse_ipv6(const char *str, guint8 *ip, guint *network, guint16 *port) {
	guint8 data[4] = {0,0,0,0};
	guint16 *predata = (guint16*) ip, postdata[8];
	size_t prec = 0, postc = 0;
	const char *p = str, *mark = NULL;
	gboolean res = TRUE, compressed = FALSE;
	int cs, tmpval = 0, i = 0;

	if (network) *network = 128;
	if (port) *port = 0;

	
#line 1205 "ip_parsers.c"
	{
	}
#line 126 "../../../src/common/ip_parsers.rl"

	cs = network
		? (port ? ipv6_parser_en_ipv6_socket_cidr : ipv6_parser_en_ipv6_cidr)
		: (port ? ipv6_parser_en_ipv6_socket      : ipv6_parser_en_ipv6);
	
#line 1214 "ip_parsers.c"
	{
	int _klen;
	const char *_keys;
	int _trans;

	if ( cs == 0 )
		goto _out;
_resume:
	_keys = _ipv6_parser_trans_keys + _ipv6_parser_key_offsets[cs];
	_trans = _ipv6_parser_index_offsets[cs];

	_klen = _ipv6_parser_single_lengths[cs];
	if ( _klen > 0 ) {
		const char *_lower = _keys;
		const char *_mid;
		const char *_upper = _keys + _klen - 1;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + ((_upper-_lower) >> 1);
			if ( (*p) < *_mid )
				_upper = _mid - 1;
			else if ( (*p) > *_mid )
				_lower = _mid + 1;
			else {
				_trans += (_mid - _keys);
				goto _match;
			}
		}
		_keys += _klen;
		_trans += _klen;
	}

	_klen = _ipv6_parser_range_lengths[cs];
	if ( _klen > 0 ) {
		const char *_lower = _keys;
		const char *_mid;
		const char *_upper = _keys + (_klen<<1) - 2;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + (((_upper-_lower) >> 1) & ~1);
			if ( (*p) < _mid[0] )
				_upper = _mid - 2;
			else if ( (*p) > _mid[1] )
				_lower = _mid + 2;
			else {
				_trans += ((_mid - _keys)>>1);
				goto _match;
			}
		}
		_trans += _klen;
	}

_match:
	_trans = _ipv6_parser_indicies[_trans];
	cs = _ipv6_parser_trans_targs[_trans];

	if ( _ipv6_parser_trans_actions[_trans] == 0 )
		goto _again;

	switch ( _ipv6_parser_trans_actions[_trans] ) {
	case 1:
#line 57 "../../../src/common/ip_parsers.rl"
	{ mark = p; }
	break;
	case 7:
#line 60 "../../../src/common/ip_parsers.rl"
	{ tmpval = 10*tmpval + ((*p) - '0'); }
	break;
	case 6:
#line 63 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 255) { res = FALSE; {p++; goto _out; } }
		data[i++] = tmpval;
	}
	break;
	case 17:
#line 67 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 128) { res = FALSE; {p++; goto _out; } }
		*network = tmpval;
	}
	break;
	case 4:
#line 100 "../../../src/common/ip_parsers.rl"
	{ compressed = TRUE; }
	break;
	case 12:
#line 103 "../../../src/common/ip_parsers.rl"
	{ cs = ipv6_parser_first_final; {p++; goto _out; } }
	break;
	case 8:
#line 59 "../../../src/common/ip_parsers.rl"
	{ tmpval = 0; }
#line 60 "../../../src/common/ip_parsers.rl"
	{ tmpval = 10*tmpval + ((*p) - '0'); }
	break;
	case 10:
#line 63 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 255) { res = FALSE; {p++; goto _out; } }
		data[i++] = tmpval;
	}
#line 89 "../../../src/common/ip_parsers.rl"
	{
		if (prec > 6) { res = FALSE; {p++; goto _out; } }
		predata[prec++] = *(guint16*) (data);
		predata[prec++] = *(guint16*) (data+2);
	}
	break;
	case 16:
#line 63 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 255) { res = FALSE; {p++; goto _out; } }
		data[i++] = tmpval;
	}
#line 94 "../../../src/common/ip_parsers.rl"
	{
		if (postc > 6) { res = FALSE; {p++; goto _out; } }
		postdata[postc++] = *(guint16*) (data);
		postdata[postc++] = *(guint16*) (data+2);
	}
	break;
	case 11:
#line 67 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 128) { res = FALSE; {p++; goto _out; } }
		*network = tmpval;
	}
#line 103 "../../../src/common/ip_parsers.rl"
	{ cs = ipv6_parser_first_final; {p++; goto _out; } }
	break;
	case 18:
#line 71 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 65535) { res = FALSE; {p++; goto _out; } }
		*port = tmpval;
	}
#line 103 "../../../src/common/ip_parsers.rl"
	{ cs = ipv6_parser_first_final; {p++; goto _out; } }
	break;
	case 3:
#line 57 "../../../src/common/ip_parsers.rl"
	{ mark = p; }
#line 59 "../../../src/common/ip_parsers.rl"
	{ tmpval = 0; }
#line 60 "../../../src/common/ip_parsers.rl"
	{ tmpval = 10*tmpval + ((*p) - '0'); }
	break;
	case 9:
#line 63 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 255) { res = FALSE; {p++; goto _out; } }
		data[i++] = tmpval;
	}
#line 89 "../../../src/common/ip_parsers.rl"
	{
		if (prec > 6) { res = FALSE; {p++; goto _out; } }
		predata[prec++] = *(guint16*) (data);
		predata[prec++] = *(guint16*) (data+2);
	}
#line 103 "../../../src/common/ip_parsers.rl"
	{ cs = ipv6_parser_first_final; {p++; goto _out; } }
	break;
	case 15:
#line 63 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 255) { res = FALSE; {p++; goto _out; } }
		data[i++] = tmpval;
	}
#line 94 "../../../src/common/ip_parsers.rl"
	{
		if (postc > 6) { res = FALSE; {p++; goto _out; } }
		postdata[postc++] = *(guint16*) (data);
		postdata[postc++] = *(guint16*) (data+2);
	}
#line 103 "../../../src/common/ip_parsers.rl"
	{ cs = ipv6_parser_first_final; {p++; goto _out; } }
	break;
	case 2:
#line 76 "../../../src/common/ip_parsers.rl"
	{ tmpval = strtol(mark, NULL, 16); }
#line 77 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 0xffff) { res = FALSE; {p++; goto _out; } }
	}
#line 80 "../../../src/common/ip_parsers.rl"
	{
		if (prec >= 8) { res = FALSE; {p++; goto _out; } }
		predata[prec++] = htons(tmpval);
	}
	break;
	case 14:
#line 76 "../../../src/common/ip_parsers.rl"
	{ tmpval = strtol(mark, NULL, 16); }
#line 77 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 0xffff) { res = FALSE; {p++; goto _out; } }
	}
#line 84 "../../../src/common/ip_parsers.rl"
	{
		if (postc >= 8) { res = FALSE; {p++; goto _out; } }
		postdata[postc++] = htons(tmpval);
	}
	break;
	case 5:
#line 76 "../../../src/common/ip_parsers.rl"
	{ tmpval = strtol(mark, NULL, 16); }
#line 77 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 0xffff) { res = FALSE; {p++; goto _out; } }
	}
#line 80 "../../../src/common/ip_parsers.rl"
	{
		if (prec >= 8) { res = FALSE; {p++; goto _out; } }
		predata[prec++] = htons(tmpval);
	}
#line 103 "../../../src/common/ip_parsers.rl"
	{ cs = ipv6_parser_first_final; {p++; goto _out; } }
	break;
	case 13:
#line 76 "../../../src/common/ip_parsers.rl"
	{ tmpval = strtol(mark, NULL, 16); }
#line 77 "../../../src/common/ip_parsers.rl"
	{
		if (tmpval > 0xffff) { res = FALSE; {p++; goto _out; } }
	}
#line 84 "../../../src/common/ip_parsers.rl"
	{
		if (postc >= 8) { res = FALSE; {p++; goto _out; } }
		postdata[postc++] = htons(tmpval);
	}
#line 103 "../../../src/common/ip_parsers.rl"
	{ cs = ipv6_parser_first_final; {p++; goto _out; } }
	break;
#line 1453 "ip_parsers.c"
	}

_again:
	if ( cs == 0 )
		goto _out;
	p += 1;
	goto _resume;
	_out: {}
	}
#line 131 "../../../src/common/ip_parsers.rl"

	if (!res || cs < ipv6_parser_first_final) return FALSE;
	if (!compressed) return (prec == 8);
	if (prec + postc > 7) return FALSE;
	for ( ; prec < 8-postc; prec++) predata[prec] = 0;
	for (postc = 0 ; prec < 8; prec++, postc++ ) predata[prec] = postdata[postc];

	return TRUE;
}

GString* li_ipv6_tostring(GString *dest, const guint8 ip[16]) {
#define IPV6_TEMPLATE "ffff:ffff:ffff:ffff:ffff:ffff:abc.def.ghi.jkl"
	guint16 *data = (guint16*) ip;
	size_t i;

#ifdef HAVE_INET_NTOP
	g_string_set_size(dest, sizeof(IPV6_TEMPLATE)-1);
	if (inet_ntop(AF_INET6, ip, dest->str, dest->len)) {
		g_string_set_size(dest, strlen(dest->str));
		return dest;
	}
#endif
	g_string_truncate(dest, 0);
	g_string_printf(dest, "%" G_GINT16_MODIFIER "x", ntohs(data[0]));
	for (i = 1; i < 8; i++) {
		g_string_append_printf(dest, ":%" G_GINT16_MODIFIER "x", ntohs(data[i]));
	}
	return dest;
}
